Lessons
=======

Here listed are the various SPICE lessons provided by the NAIF translated to
use python code examples. Please refer to the NAIF lessons for the kernel
files needed.

Contents:

.. toctree::
   :maxdepth: 1

   basics


